@@ -14,36 +14,18 @@ else:
     from typing_extensions import Protocol
 
 T = TypeVar("T")
-FutureT = Union["asyncio.Future[T]", Generator[Any, None, T], Awaitable[T]]
-
-if sys.version_info >= (3, 7):
-    from contextlib import asynccontextmanager
-
-    get_running_loop = asyncio.get_running_loop
-
-else:
-    from ._context import asynccontextmanager
-
-    get_running_loop = asyncio.get_event_loop
-
+FutureT: "TypeAlias" = Union["asyncio.Future[T]", Generator[Any, None, T], Awaitable[T]]
 
 if sys.version_info >= (3, 8):
     create_task = asyncio.create_task
 
-elif sys.version_info >= (3, 7):
+else:
 
     def create_task(
         coro: FutureT[T], name: Optional[str] = None
     ) -> "asyncio.Future[T]":
         return asyncio.create_task(coro)
 
-else:
-
-    def create_task(
-        coro: FutureT[T], name: Optional[str] = None
-    ) -> "asyncio.Future[T]":
-        return asyncio.ensure_future(coro)
-
 
 if sys.version_info >= (3, 9):
     from zoneinfo import ZoneInfo
@@ -52,12 +34,23 @@ else:
     from backports.zoneinfo import ZoneInfo
     from typing import Counter, Deque
 
+if sys.version_info >= (3, 10):
+    from typing import TypeAlias, TypeGuard
+else:
+    from typing_extensions import TypeAlias, TypeGuard
+
+if sys.version_info >= (3, 11):
+    from typing import LiteralString
+else:
+    from typing_extensions import LiteralString
+
 __all__ = [
     "Counter",
     "Deque",
+    "LiteralString",
     "Protocol",
+    "TypeAlias",
+    "TypeGuard",
     "ZoneInfo",
-    "asynccontextmanager",
     "create_task",
-    "get_running_loop",
 ]
